@@ -74,7 +74,7 @@ pub struct NetworkStatus {
     pub security_groups: BTreeMap<SecurityGroupRole, SecurityGroup>, // `json:"securityGroups,omitempty"`
 
     /// APIServerELB is the Kubernetes api server classic load balancer.
-    pub api_server_elb: ClassicELB, // `json:"apiServerElb,omitempty"`
+    pub api_server_elb: Option<ClassicELB>, // `json:"apiServerElb,omitempty"`
 }
 
 /// ClassicELBScheme defines the scheme of a classic load balancer.
